package md

import (
	"code.fnuoos.com/EggPlanet/egg_system_rules.git/rule/egg_energy/md"
	"time"
)

type VirtualCoin struct {
	Id            int       `json:"id" `
	Name          string    `json:"name" `           // 名称
	ExchangeRatio string    `json:"exchange_ratio" ` // 兑换比例(与金额)
	IsUse         int       `json:"is_use" `         // 是否开启: 0否 1是
	CreateAt      time.Time `json:"create_at" `
	UpdateAt      time.Time `json:"update_at" `
}

// BasicSetting 基础设置
type BasicSetting struct {
	IsOpen                int    `json:"is_open" `                   // 是否开启(1：开启 0：关闭)
	PersonEggEnergyCoinId int    `json:"person_egg_energy_coin_id" ` // 个人蛋蛋能量对应虚拟币 id
	TeamEggEnergyCoinId   int    `json:"team_egg_energy_coin_id" `   // 团队蛋蛋能量对应虚拟币 id
	PersonEggPointsCoinId int    `json:"person_egg_points_coin_id" ` // 个人蛋蛋积分对应虚拟币 id
	TeamEggPointsCoinId   int    `json:"team_egg_points_coin_id" `   // 团队蛋蛋积分对应虚拟币 id
	DirectPushReward      string `json:"direct_push_reward" `        // 直推奖励
}

// VideoRewardSetting 视频奖励
type VideoRewardSetting struct {
	VideoRewardIsOpen int                        `json:"video_reward_is_open" ` // 视频奖励是否开启(1:开启 0:关闭)
	VideoRewardSystem md.VideoRewardSystemStruct `json:"video_reward_system"`   // 视频奖励机制
}

// DataSetting 数据设置
type DataSetting struct {
	TotalIssuanceAmount        string `json:"total_issuance_amount"`        // 总发行量
	TotalTechnologyTeam        string `json:"total_technology_team"`        // 技术团队
	TotalAngelInvestor         string `json:"total_angel_investor"`         // 天使投资人
	TotalOperateFund           string `json:"total_operate_fund"`           // 运营资金
	TotalEcologicalDevelopment string `json:"total_ecological_development"` // 生态建设
	TotalUserForPerson         string `json:"total_user_for_person"`        // 个人区域
	TotalUserForTeam           string `json:"total_user_for_team"`          // 团队区域

}

type GetEggEnergyBasicResp struct {
	BasicSetting       BasicSetting                `json:"basic_setting"`        // 基础设置
	VideoRewardSetting VideoRewardSetting          `json:"video_reward_setting"` // 视频奖励
	DataSetting        DataSetting                 `json:"data_setting"`         // 数据设置
	DestructionSetting md.DestructionSettingStruct `json:"destruction_setting"`  // 销毁设置
	PriceSetting       md.PriceSettingStruct       `json:"price_setting"`        // 价格设置
	ExchangeRules      md.ExchangeRulesStruct      `json:"exchange_rules"`       // 兑换规则
	RewardSystem       md.RewardSystemStruct       `json:"reward_system"`        // 圈层奖励
	SystemID           int                         `json:"system_id"`            // 该设置系统 ID
}

type UpdateEggEnergyBasicReq struct {
	SystemID           int                         `json:"system_id,required"`   // 该设置系统 ID
	BasicSetting       BasicSetting                `json:"basic_setting"`        // 基础设置
	VideoRewardSetting VideoRewardSetting          `json:"video_reward_setting"` // 视频奖励
	DataSetting        DataSetting                 `json:"data_setting"`         // 数据设置
	DestructionSetting md.DestructionSettingStruct `json:"destruction_setting"`  // 销毁设置
	PriceSetting       md.PriceSettingStruct       `json:"price_setting"`        // 价格设置
	ExchangeRules      md.ExchangeRulesStruct      `json:"exchange_rules"`       // 兑换规则
	RewardSystem       md.RewardSystemStruct       `json:"reward_system"`        // 圈层奖励
}
